@@ -13,7 +13,6 @@
 #include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
-#include <kcalendarcore_version.h>
 #include <KCalendarCore/MemoryCalendar>
 #include <KCalendarCore/ICalFormat>
 
@@ -96,8 +95,8 @@ bool DisplayCalendar::open()
 
     if (!mOpen)
     {
-        mCalendarStorage->calendar().clear();
-        mCalendarStorage.clear();
+        mCalendarStorage->calendar().reset();
+        mCalendarStorage.reset();
     }
     return mOpen;
 }
@@ -127,11 +126,8 @@ int DisplayCalendar::load()
         KAMessageBox::error(MainWindow::mainMainWindow(),
                             xi18nc("@info", "<para>Error loading calendar:</para><para><filename>%1</filename></para><para>Please fix or delete the file.</para>", mDisplayCalPath));
         // load() could have partially populated the calendar, so clear it out
-#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        mCalendarStorage->calendar()->close();
-#endif
-        mCalendarStorage->calendar().clear();
-        mCalendarStorage.clear();
+        mCalendarStorage->calendar().reset();
+        mCalendarStorage.reset();
         mOpen = false;
         return -1;
     }
@@ -192,11 +188,8 @@ void DisplayCalendar::close()
 {
     if (mCalendarStorage)
     {
-#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        mCalendarStorage->calendar()->close();
-#endif
-        mCalendarStorage->calendar().clear();
-        mCalendarStorage.clear();
+        mCalendarStorage->calendar().reset();
+        mCalendarStorage.reset();
     }
 
     // Flag as closed now to prevent removeKAEvents() doing silly things
@@ -271,7 +264,7 @@ bool DisplayCalendar::addEvent(KAEvent& evnt)
     id = CalEvent::uid(id, type);   // include the alarm type tag in the ID
     kcalEvent->setUid(id);
     event->setEventId(id);
-    event->updateKCalEvent(kcalEvent, KAEvent::UID_IGNORE);
+    event->updateKCalEvent(kcalEvent, KAEvent::UidAction::Ignore);
 
     bool ok = false;
     bool remove = false;
@@ -333,17 +326,6 @@ bool DisplayCalendar::deleteEvent(const QString& eventID, bool saveit)
         {
             status = CalEvent::status(kcalEvent);
             mCalendarStorage->calendar()->deleteEvent(kcalEvent);
-            if (mCalendarStorage->calendar()->rawEvents().isEmpty())
-            {
-                // Workaround for memory leak in KF5 KCalendarCore !!!
-                // All events deleted from the calendar are stored until the
-                // calendar is closed (the function to disable this,
-                // Calendar::setDeletionTracking(), is protected!). The only
-                // way to clear this memory leak is to close the calendar
-                // whenever it is empty.
-                // Note that calling close() leaves the calendar open and usable!
-                mCalendarStorage->calendar()->close();
-            }
         }
 
         if (status != CalEvent::EMPTY)
