@@ -1,7 +1,7 @@
 /*
  *  messagenotification.cpp  -  displays an alarm message in a system notification
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -16,6 +16,7 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
+#include <KWindowSystem>
 #ifdef RESTORE_NOTIFICATIONS
 #include <KConfigGroup>
 #include <KConfigGui>
@@ -37,9 +38,6 @@ const QString BeepId    = QStringLiteral("MessageBeep");
 const QString SpeakId   = QStringLiteral("MessageSpeak");
 const QString ErrorId   = QStringLiteral("MessageError");
 
-// Flags for the notification
-const KNotification::NotificationFlags NFLAGS = KNotification::RaiseWidgetOnActivation;
-
 const QString NL = QStringLiteral("\n");
 const QString SP = QStringLiteral(" ");
 
@@ -95,10 +93,10 @@ private Q_SLOTS:
         for (MessageNotification* notif : std::as_const(MessageNotification::mNotificationList))
         {
             const QByteArray group = "Notification_" + QByteArray::number(++n);
-            KConfigGroup cg(config, group.constData());
+            KConfigGroup cg(config, QLatin1String(group.constData()));
             notif->saveProperties(cg);
         }
-        KConfigGroup cg(config, "Number");
+        KConfigGroup cg(config, QStringLiteral("Number"));
         cg.writeEntry("NumberOfNotifications", MessageNotification::mNotificationList.count());
     }
 #endif
@@ -109,8 +107,7 @@ private:
 
 MNSessionManager* MNSessionManager::mInstance = nullptr;
 
-
-QVector<MessageNotification*> MessageNotification::mNotificationList;
+QList<MessageNotification*> MessageNotification::mNotificationList;
 
 /******************************************************************************
 * Restore MessageNotification instances saved at session shutdown.
@@ -121,7 +118,7 @@ void MessageNotification::sessionRestore()
     KConfig* config = KConfigGui::sessionConfig();
     if (config)
     {
-        KConfigGroup cg(config, "Number");
+        KConfigGroup cg(config, QStringLiteral("Number"));
         const int count = cg.readEntry("NumberOfNotifications", 0);
         for (int n = 1;  n <= count;  ++n)
         {
@@ -150,16 +147,14 @@ void MessageNotification::sessionRestore()
 * displayed.
 */
 MessageNotification::MessageNotification(const KAEvent& event, const KAAlarm& alarm, int flags)
-    : KNotification(getNotifyEventId(event), NFLAGS)
+    : KNotification(getNotifyEventId(event))
     , MessageDisplay(event, alarm, flags)
 {
     qCDebug(KALARM_LOG) << "MessageNotification():" << mEventId();
     MNSessionManager::create();
-    setWidget(MainWindow::mainMainWindow());
     if (!(flags & NoInitView))
         MessageNotification::setUpDisplay();    // avoid calling virtual method from constructor
 
-    connect(this, &KNotification::activated, this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
     connect(mHelper, &MessageDisplayHelper::commandExited, this, &MessageNotification::commandCompleted);
@@ -174,15 +169,13 @@ MessageNotification::MessageNotification(const KAEvent& event, const KAAlarm& al
 */
 MessageNotification::MessageNotification(const KAEvent& event, const DateTime& alarmDateTime,
                        const QStringList& errmsgs, const QString& dontShowAgain)
-    : KNotification(ErrorId, NFLAGS)
+    : KNotification(ErrorId)
     , MessageDisplay(event, alarmDateTime, errmsgs, dontShowAgain)
 {
     qCDebug(KALARM_LOG) << "MessageNotification(errmsg)";
     MNSessionManager::create();
-    setWidget(MainWindow::mainMainWindow());
     MessageNotification::setUpDisplay();    // avoid calling virtual method from constructor
 
-    connect(this, &KNotification::activated, this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
 
@@ -195,14 +188,12 @@ MessageNotification::MessageNotification(const KAEvent& event, const DateTime& a
 * Ownership of the helper is taken by the new instance.
 */
 MessageNotification::MessageNotification(const QString& eventId, MessageDisplayHelper* helper)
-    : KNotification(eventId, NFLAGS)
+    : KNotification(eventId)
     , MessageDisplay(helper)
 {
     qCDebug(KALARM_LOG) << "MessageNotification(helper):" << mEventId();
     MNSessionManager::create();
-    setWidget(MainWindow::mainMainWindow());
 
-    connect(this, &KNotification::activated, this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
     connect(mHelper, &MessageDisplayHelper::commandExited, this, &MessageNotification::commandCompleted);
@@ -242,7 +233,7 @@ void MessageNotification::setUpDisplay()
         // It's a normal alarm message notification
         switch (mAction())
         {
-            case KAEvent::FILE:
+            case KAEvent::SubAction::File:
                 // Display the file name
                 mMessageText = texts.fileName + NL;
 
@@ -251,9 +242,9 @@ void MessageNotification::setUpDisplay()
                     // Display contents of file
                     switch (texts.fileType)
                     {
-                        case File::Image:
+                        case File::Type::Image:
                             break;   // can't display an image
-                        case File::TextFormatted:
+                        case File::Type::TextFormatted:
                         default:
                             mMessageText += texts.message;
                             break;
@@ -261,16 +252,16 @@ void MessageNotification::setUpDisplay()
                 }
                 break;
 
-            case KAEvent::MESSAGE:
+            case KAEvent::SubAction::Message:
                 mMessageText = texts.message;
                 break;
 
-            case KAEvent::COMMAND:
+            case KAEvent::SubAction::Command:
                 mMessageText = texts.message;
                 mCommandInhibit = true;
                 break;
 
-            case KAEvent::EMAIL:
+            case KAEvent::SubAction::Email:
             default:
                 break;
         }
@@ -286,16 +277,16 @@ void MessageNotification::setUpDisplay()
         // It's an error message
         switch (mAction())
         {
-            case KAEvent::EMAIL:
+            case KAEvent::SubAction::Email:
             {
                 // Display the email addresses and subject.
                 mMessageText = texts.errorEmail[0] + SP + texts.errorEmail[1] + NL
                              + texts.errorEmail[2] + SP + texts.errorEmail[3] + NL;
                 break;
             }
-            case KAEvent::COMMAND:
-            case KAEvent::FILE:
-            case KAEvent::MESSAGE:
+            case KAEvent::SubAction::Command:
+            case KAEvent::SubAction::File:
+            case KAEvent::SubAction::Message:
             default:
                 // Just display the error message strings
                 break;
@@ -335,7 +326,7 @@ int MessageNotification::notificationCount()
 */
 QWidget* MessageNotification::displayParent()
 {
-    return widget();
+    return MainWindow::mainMainWindow();
 }
 
 void MessageNotification::closeDisplay()
@@ -361,7 +352,7 @@ void MessageNotification::showDisplay()
             // doesn't do this when the notification is displayed.
             mHelper->wakeScreen();
         }
-        if (!mDisplayComplete  &&  !mErrorWindow()  &&  mAlarmType() != KAAlarm::INVALID_ALARM)
+        if (!mDisplayComplete  &&  !mErrorWindow()  &&  mAlarmType() != KAAlarm::Type::Invalid)
             mHelper->displayComplete(false);   // reschedule
         mDisplayComplete = true;
     }
@@ -472,9 +463,6 @@ void MessageNotification::textsChanged(MessageDisplayHelper::DisplayTexts::TextI
 
     if (textChanged)
         setNotificationText();
-
-    // Update the notification. Note that this does nothing if no changes have occurred.
-    update();
 }
 
 /******************************************************************************
@@ -518,7 +506,6 @@ void MessageNotification::setNotificationTitle(const QString& text)
 void MessageNotification::setNotificationText()
 {
     setText(mMessageText + NL + mTimeText + NL + QStringLiteral("<i>") + mRemainingText + QStringLiteral("</i>"));
-update();
 }
 
 /******************************************************************************
@@ -526,21 +513,26 @@ update();
 */
 void MessageNotification::setNotificationButtons()
 {
-    mEditButtonIndex = -1;
-    mDeferButtonIndex = -1;
-    QStringList buttons;
     if (mEnableEdit)
     {
-        mEditButtonIndex = 0;
-        buttons += i18nc("@action:button", "Edit");
+        auto editAction = addAction(i18nc("@action:button", "Edit"));
+        connect(editAction, &KNotificationAction::activated, this, [this] {
+            if (mHelper->createEdit())
+                mHelper->executeEdit();
+        });
     }
+
     if (mEnableDefer)
     {
-        mDeferButtonIndex = buttons.count();
-        buttons += i18nc("@action:button", "Defer");
+        auto deferAction = addAction(i18nc("@action:button", "Defer"));
+        connect(deferAction, &KNotificationAction::activated, this, [this] {
+            DeferDlgData* data = createDeferDlg(this, true);
+            executeDeferDlg(data);
+        });
     }
-    setActions(buttons);
-    setDefaultAction(KAboutData::applicationData().displayName());
+
+    auto defaultAction = addDefaultAction(KAboutData::applicationData().displayName());
+    connect(defaultAction, &KNotificationAction::activated, this, &MessageNotification::slotDefaultActivated);
 }
 
 bool MessageNotification::isDeferButtonEnabled() const
@@ -574,26 +566,13 @@ void MessageNotification::saveProperties(KConfigGroup& config)
 }
 
 /******************************************************************************
-* Called when a button in the notification has been pressed.
-* Button indexes start at 1.
+* Called when the default action in the notification has been pressed, to show
+* the main window.
 */
-void MessageNotification::buttonActivated(unsigned int index)
+void MessageNotification::slotDefaultActivated()
 {
-    int i = static_cast<int>(index);
-    if (i == 0)
-    {
-        displayMainWindow();
-    }
-    else if (i == mEditButtonIndex + 1)
-    {
-        if (mHelper->createEdit())
-            mHelper->executeEdit();
-    }
-    else if (i == mDeferButtonIndex + 1)
-    {
-        DeferDlgData* data = createDeferDlg(this, true);
-        executeDeferDlg(data);
-    }
+    KWindowSystem::setCurrentXdgActivationToken(xdgActivationToken());
+    displayMainWindow();
 }
 
 /******************************************************************************
@@ -609,5 +588,6 @@ void MessageNotification::slotClosed()
 }
 
 #include "messagenotification.moc"
+#include "moc_messagenotification.cpp"
 
 // vim: et sw=4:
