@@ -447,7 +447,7 @@ QByteArray ResourceCheckListModel::debugType(const char* func) const
 = Proxy model providing a checkable resource list, filtered to contain only one
 = alarm type. The selected alarm type may be changed as desired.
 =============================================================================*/
-QVector<ResourceFilterCheckListModel*> ResourceFilterCheckListModel::mInstances;
+QList<ResourceFilterCheckListModel*> ResourceFilterCheckListModel::mInstances;
 
 ResourceFilterCheckListModel::ResourceFilterCheckListModel(QObject* parent)
     : QSortFilterProxyModel(parent)
@@ -723,13 +723,11 @@ bool ResourceView::viewportEvent(QEvent* e)
 
 QStyleOptionViewItem ResourceView::listViewOptions() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    return QListView::viewOptions();
-#else
     QStyleOptionViewItem option;
     initViewItemOption(&option);
     return option;
-#endif
 }
 
+#include "moc_resourcemodel.cpp"
+
 // vim: et sw=4:
